@@ -10,7 +10,8 @@ pub struct CreateStreamRequest {
 }
 
 impl CreateStreamRequest {
-    #[allow(clippy::new_ret_no_self)]
+    //noinspection ALL
+    #[allow(dead_code, clippy::new_ret_no_self)]
     pub fn new<'s, S: Into<Option<&'s str>>>(s: S) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_create",
@@ -29,7 +30,8 @@ pub struct PushRequest {
 }
 
 impl PushRequest {
-    #[allow(clippy::new_ret_no_self)]
+    //noinspection ALL
+    #[allow(dead_code, clippy::new_ret_no_self)]
     pub fn new<T: Into<Vec<u8>>>(request_id: usize, data: T) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_push",
@@ -50,7 +52,8 @@ pub struct PullRequest {
 }
 
 impl PullRequest {
-    #[allow(clippy::new_ret_no_self)]
+    //noinspection ALL
+    #[allow(dead_code, clippy::new_ret_no_self)]
     pub fn new(request_id: usize, index: usize, limit: usize) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_pull",
@@ -78,6 +81,8 @@ pub enum Index {
 }
 
 impl Index {
+    //noinspection ALL
+    #[allow(dead_code)]
     pub fn get<S: Into<String>>(stream_name: S, client_id: S) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_index",
@@ -88,6 +93,8 @@ impl Index {
         )
     }
 
+    //noinspection ALL
+    #[allow(dead_code)]
     pub fn save<S: Into<String>>(stream_name: S, client_id: S, index: usize) -> ProtocolPayload {
         ProtocolPayload::new(
             "stream_index",
